@@ -8,17 +8,18 @@
 #' double-click inside one of its cells, edit the value, then close the table.
 #' In \code{'input'} mode, a label table that was generated in \code{'manual'} mode is re-used.
 #'
-#' @param mode either \code{'auto'}, \code{'manual'} or \code{'input'}. See Description above.
-#' @param layer in \code{'auto'} mode, single or vector of characters, may only be one, some or all of: 
-#' \code{c("ASDs","SSRUs","RBs","SSMUs","MAs","RefAreas","MPAs","EEZs")}.
-#' @param fontsize in \code{'auto'} mode, size of the text.
-#' @param fonttype in \code{'auto'} mode, type of the text (1 to 4), where 1 corresponds to plain text, 
+#' @param mode character, either \code{'auto'}, \code{'manual'} or \code{'input'}. See Description above.
+#' @param layer character, in \code{'auto'} mode, single or vector of characters, may only be one, some or all of: 
+#' \code{c("ASDs","SSRUs","RBs","SSMUs","MAs","MPAs","EEZs")}.
+#' @param fontsize numeric, in \code{'auto'} mode, size of the text.
+#' @param fonttype numeric, in \code{'auto'} mode, type of the text (1 to 4), where 1 corresponds to plain text, 
 #' 2 to bold face, 3 to italic and 4 to bold italic.
-#' @param angle in \code{'auto'} mode, rotation of the text in degrees.
-#' @param col in \code{'auto'} mode, color of the text.
-#' @param LabelTable in \code{'input'} mode, a label table that was generated in \code{'manual'} mode.
+#' @param angle numeric, in \code{'auto'} mode, rotation of the text in degrees.
+#' @param col character, in \code{'auto'} mode, color of the text.
+#' @param LabelTable in \code{'input'} mode, name of the label table that was generated in \code{'manual'} mode.
 #' @return Adds labels to plot. To save a label table generated in \code{'manual'} mode, use:
-#' \code{MyLabelTable=add_labels(mode='auto')}. To re-use that label table, use: 
+#' \code{MyLabelTable=add_labels(mode='auto')}. 
+#' To re-use that label table, use: 
 #' \code{add_labels(mode='input',LabelTable=MyLabelTable)}.
 #' 
 #' @seealso 
@@ -33,13 +34,13 @@
 #' #Example 1: 'auto' mode
 #' #label ASDs in bold and red
 #' ASDs=load_ASDs()
-#' plot(ASDs)
+#' plot(st_geometry(ASDs))
 #' add_labels(mode='auto',layer='ASDs',fontsize=1,fonttype=2,col='red')
 #' #add MPAs and EEZs and their labels in large, green and vertical text
 #' MPAs=load_MPAs()
 #' EEZs=load_EEZs()
-#' plot(MPAs,add=TRUE,border='green')
-#' plot(EEZs,add=TRUE,border='green')
+#' plot(st_geometry(MPAs),add=TRUE,border='green')
+#' plot(st_geometry(EEZs),add=TRUE,border='green')
 #' add_labels(mode='auto',layer=c('EEZs','MPAs'),fontsize=2,col='green',angle=90)
 #' 
 #' 
@@ -47,13 +48,13 @@
 #' #Examples 2 and 3 below are commented (remove the # to test)
 #' #plot(SmallBathy)
 #' #ASDs=load_ASDs()
-#' #plot(ASDs,add=TRUE)
+#' #plot(st_geometry(ASDs),add=TRUE)
 #' #MyLabels=add_labels(mode='manual')
 #' 
 #' 
 #' #Example 3: Re-use the label table generated in Example 2
 #' #plot(SmallBathy)
-#' #plot(ASDs,add=TRUE)
+#' #plot(st_geometry(ASDs),add=TRUE)
 #' #add_labels(mode='input',LabelTable=MyLabels)
 #' 
 #' 
@@ -81,13 +82,12 @@ add_labels=function(mode=NULL,layer=NULL,fontsize=1,fonttype=1,angle=0,col='blac
       col=character()
     )
     ls=par("usr")
-    Gr=raster(extent(ls),nrows=100,ncols=100)
-    Gr=setValues(Gr,NA)
+    Gr=terra::rast(terra::ext(ls),nrows=100,ncols=100,vals=NA)
     #First label
     replayPlot(P)
     message('Click on your figure to add a label\n')
     message('Then edit the label table and close it\n')
-    a=click(Gr,xy=TRUE,n=1,show=FALSE)
+    a=terra::click(Gr,xy=TRUE,n=1,show=FALSE,type="n")
     Lab=rbind(Lab,
               data.frame(
                 x=a$x,
@@ -124,7 +124,7 @@ add_labels=function(mode=NULL,layer=NULL,fontsize=1,fonttype=1,angle=0,col='blac
             if(xx==1){
         message('Click on your figure to add a label\n')
         message('Then edit the label table and close it\n')
-        a=click(Gr,xy=TRUE,n=1,show=FALSE)
+        a=terra::click(Gr,xy=TRUE,n=1,show=FALSE,type="n")
         Lab=rbind(Lab,
                        project_data(Input=data.frame(
                        x=a$x,
@@ -182,4 +182,4 @@ add_labels=function(mode=NULL,layer=NULL,fontsize=1,fonttype=1,angle=0,col='blac
            col=Lab$col[Lab$angle==ang])
     }
   }
-}
\ No newline at end of file
+}
