@@ -1,8 +1,8 @@
 #' Load CCAMLR statistical Areas, Subareas and Divisions
 #'
-#' Download the up-to-date spatial layer from the \href{http://gis.ccamlr.org/}{online CCAMLRGIS} and load it to your environment.
+#' Download the up-to-date spatial layer from the online CCAMLRGIS (\url{http://gis.ccamlr.org/}) and load it to your environment.
 #' See examples for offline use. All layers use the Lambert azimuthal equal-area projection
-#'  (EPSG:6932; CRS:+proj=laea +lat_0=-90 +lon_0=0 +x_0=0 +y_0=0 +datum=WGS84 +units=m +no_defs)
+#'  (\code{\link{CCAMLRp}})
 #'
 #' @seealso 
 #' \code{\link{load_SSRUs}}, \code{\link{load_RBs}},
@@ -15,12 +15,13 @@
 #' 
 #' #When online:
 #' ASDs=load_ASDs()
-#' plot(ASDs)
+#' plot(st_geometry(ASDs))
 #' 
 #' #If going offline in the future: load and save as RData when online,
-#' # then reload RData when offline:
+#' #then reload RData when offline:
 #' ASDs=load_ASDs()
 #' EEZs=load_EEZs()
+#' #N.B.: replace tempdir() with folder location of your choice
 #' save(list=c('ASDs','EEZs'), file = file.path(tempdir(), "CCAMLRLayers.RData"))
 #' rm(ASDs,EEZs)
 #' load(file.path(tempdir(), "CCAMLRLayers.RData"))
@@ -30,16 +31,16 @@
 load_ASDs=function(){
   #NB: use http not https
   ccamlrgisurl="http://gis.ccamlr.org/geoserver/gis/ows?service=WFS&version=1.0.0&request=GetFeature&typeName=gis:statistical_areas_6932&outputFormat=json"
-  CCAMLR_data=suppressWarnings(readOGR(dsn=ccamlrgisurl,layer="OGRGeoJSON",verbose = FALSE))
-  CCAMLR_data=spTransform(CCAMLR_data,CRS("+init=epsg:6932"))
+  CCAMLR_data = st_read(ccamlrgisurl,quiet = TRUE)
+  CCAMLR_data = st_transform(CCAMLR_data,6932)
   return(CCAMLR_data)
 }
 
 #' Load CCAMLR Small Scale Research Units
 #'
-#' Download the up-to-date spatial layer from the \href{http://gis.ccamlr.org/}{online CCAMLRGIS} and load it to your environment.
+#' Download the up-to-date spatial layer from the online CCAMLRGIS (\url{http://gis.ccamlr.org/}) and load it to your environment.
 #' See examples for offline use. All layers use the Lambert azimuthal equal-area projection
-#'  (EPSG:6932; CRS:+proj=laea +lat_0=-90 +lon_0=0 +x_0=0 +y_0=0 +datum=WGS84 +units=m +no_defs)
+#'  (\code{\link{CCAMLRp}})
 #'
 #' @seealso 
 #' \code{\link{load_ASDs}}, \code{\link{load_RBs}},
@@ -52,12 +53,13 @@ load_ASDs=function(){
 #' 
 #' #When online:
 #' SSRUs=load_SSRUs()
-#' plot(SSRUs)
+#' plot(st_geometry(SSRUs))
 #' 
 #' #If going offline in the future: load and save as RData when online,
-#' # then reload RData when offline:
+#' #then reload RData when offline:
 #' SSRUs=load_SSRUs()
 #' EEZs=load_EEZs()
+#' #N.B.: replace tempdir() with folder location of your choice
 #' save(list=c('SSRUs','EEZs'), file = file.path(tempdir(), "CCAMLRLayers.RData"))
 #' rm(SSRUs,EEZs)
 #' load(file.path(tempdir(), "CCAMLRLayers.RData"))
@@ -67,16 +69,16 @@ load_ASDs=function(){
 load_SSRUs=function(){
   #NB: use http not https
   ccamlrgisurl="http://gis.ccamlr.org/geoserver/gis/ows?service=WFS&version=1.0.0&request=GetFeature&typeName=gis:ssrus_6932&outputFormat=json"
-  CCAMLR_data=suppressWarnings(readOGR(dsn=ccamlrgisurl,layer="OGRGeoJSON",verbose = FALSE))
-  CCAMLR_data=spTransform(CCAMLR_data,CRS("+init=epsg:6932"))
+  CCAMLR_data = st_read(ccamlrgisurl,quiet = TRUE)
+  CCAMLR_data = st_transform(CCAMLR_data,6932)
   return(CCAMLR_data)
 }
 
 #' Load the full CCAMLR Coastline
 #' 
-#' Download the up-to-date spatial layer from the \href{http://gis.ccamlr.org/}{online CCAMLRGIS} and load it to your environment.
+#' Download the up-to-date spatial layer from the online CCAMLRGIS (\url{http://gis.ccamlr.org/}) and load it to your environment.
 #' See examples for offline use. All layers use the Lambert azimuthal equal-area projection
-#'  (EPSG:6932; CRS:+proj=laea +lat_0=-90 +lon_0=0 +x_0=0 +y_0=0 +datum=WGS84 +units=m +no_defs)
+#'  (\code{\link{CCAMLRp}})
 #' Note that this coastline expands further north than \link{Coast}.
 #'
 #' @seealso 
@@ -90,12 +92,13 @@ load_SSRUs=function(){
 #' 
 #' #When online:
 #' Coastline=load_Coastline()
-#' plot(Coastline)
+#' plot(st_geometry(Coastline))
 #' 
 #' #If going offline in the future: load and save as RData when online,
-#' # then reload RData when offline:
+#' #then reload RData when offline:
 #' Coastline=load_Coastline()
 #' EEZs=load_EEZs()
+#' #N.B.: replace tempdir() with folder location of your choice
 #' save(list=c('Coastline','EEZs'), file = file.path(tempdir(), "CCAMLRLayers.RData"))
 #' rm(Coastline,EEZs)
 #' load(file.path(tempdir(), "CCAMLRLayers.RData"))
@@ -105,16 +108,16 @@ load_SSRUs=function(){
 load_Coastline=function(){
   #NB: use http not https
   ccamlrgisurl="http://gis.ccamlr.org/geoserver/gis/ows?service=WFS&version=1.0.0&request=GetFeature&typeName=gis:coastline_6932&outputFormat=json"
-  CCAMLR_data=suppressWarnings(readOGR(dsn=ccamlrgisurl,layer="OGRGeoJSON",verbose = FALSE))
-  CCAMLR_data=spTransform(CCAMLR_data,CRS("+init=epsg:6932"))
+  CCAMLR_data = st_read(ccamlrgisurl,quiet = TRUE)
+  CCAMLR_data = st_transform(CCAMLR_data,6932)
   return(CCAMLR_data)
 }
 
 #' Load CCAMLR Research Blocks
 #'
-#' Download the up-to-date spatial layer from the \href{http://gis.ccamlr.org/}{online CCAMLRGIS} and load it to your environment.
+#' Download the up-to-date spatial layer from the online CCAMLRGIS (\url{http://gis.ccamlr.org/}) and load it to your environment.
 #' See examples for offline use. All layers use the Lambert azimuthal equal-area projection
-#'  (EPSG:6932; CRS:+proj=laea +lat_0=-90 +lon_0=0 +x_0=0 +y_0=0 +datum=WGS84 +units=m +no_defs)
+#'  (\code{\link{CCAMLRp}})
 #'
 #' @seealso 
 #' \code{\link{load_ASDs}}, \code{\link{load_SSRUs}},
@@ -127,12 +130,13 @@ load_Coastline=function(){
 #' 
 #' #When online:
 #' RBs=load_RBs()
-#' plot(RBs)
+#' plot(st_geometry(RBs))
 #' 
 #' #If going offline in the future: load and save as RData when online,
-#' # then reload RData when offline:
+#' #then reload RData when offline:
 #' RBs=load_RBs()
 #' EEZs=load_EEZs()
+#' #N.B.: replace tempdir() with folder location of your choice
 #' save(list=c('RBs','EEZs'), file = file.path(tempdir(), "CCAMLRLayers.RData"))
 #' rm(RBs,EEZs)
 #' load(file.path(tempdir(), "CCAMLRLayers.RData"))
@@ -142,16 +146,16 @@ load_Coastline=function(){
 load_RBs=function(){
   #NB: use http not https
   ccamlrgisurl="http://gis.ccamlr.org/geoserver/gis/ows?service=WFS&version=1.0.0&request=GetFeature&typeName=gis:research_blocks_6932&outputFormat=json"
-  CCAMLR_data=suppressWarnings(readOGR(dsn=ccamlrgisurl,layer="OGRGeoJSON",verbose = FALSE))
-  CCAMLR_data=spTransform(CCAMLR_data,CRS("+init=epsg:6932"))
+  CCAMLR_data = st_read(ccamlrgisurl,quiet = TRUE)
+  CCAMLR_data = st_transform(CCAMLR_data,6932)
   return(CCAMLR_data)
 }
 
 #' Load CCAMLR Small Scale Management Units
 #'
-#' Download the up-to-date spatial layer from the \href{http://gis.ccamlr.org/}{online CCAMLRGIS} and load it to your environment.
+#' Download the up-to-date spatial layer from the online CCAMLRGIS (\url{http://gis.ccamlr.org/}) and load it to your environment.
 #' See examples for offline use. All layers use the Lambert azimuthal equal-area projection
-#'  (EPSG:6932; CRS:+proj=laea +lat_0=-90 +lon_0=0 +x_0=0 +y_0=0 +datum=WGS84 +units=m +no_defs)
+#'  (\code{\link{CCAMLRp}})
 #'
 #' @seealso 
 #' \code{\link{load_ASDs}}, \code{\link{load_SSRUs}}, \code{\link{load_RBs}},
@@ -164,12 +168,13 @@ load_RBs=function(){
 #' 
 #' #When online:
 #' SSMUs=load_SSMUs()
-#' plot(SSMUs)
+#' plot(st_geometry(SSMUs))
 #' 
 #' #If going offline in the future: load and save as RData when online,
-#' # then reload RData when offline:
+#' #then reload RData when offline:
 #' SSMUs=load_SSMUs()
 #' EEZs=load_EEZs()
+#' #N.B.: replace tempdir() with folder location of your choice
 #' save(list=c('SSMUs','EEZs'), file = file.path(tempdir(), "CCAMLRLayers.RData"))
 #' rm(SSMUs,EEZs)
 #' load(file.path(tempdir(), "CCAMLRLayers.RData"))
@@ -179,16 +184,16 @@ load_RBs=function(){
 load_SSMUs=function(){
   #NB: use http not https
   ccamlrgisurl="http://gis.ccamlr.org/geoserver/gis/ows?service=WFS&version=1.0.0&request=GetFeature&typeName=gis:ssmus_6932&outputFormat=json"
-  CCAMLR_data=suppressWarnings(readOGR(dsn=ccamlrgisurl,layer="OGRGeoJSON",verbose = FALSE))
-  CCAMLR_data=spTransform(CCAMLR_data,CRS("+init=epsg:6932"))
+  CCAMLR_data = st_read(ccamlrgisurl,quiet = TRUE)
+  CCAMLR_data = st_transform(CCAMLR_data,6932)
   return(CCAMLR_data)
 }
 
 #' Load CCAMLR Management Areas
 #'
-#' Download the up-to-date spatial layer from the \href{http://gis.ccamlr.org/}{online CCAMLRGIS} and load it to your environment.
+#' Download the up-to-date spatial layer from the online CCAMLRGIS (\url{http://gis.ccamlr.org/}) and load it to your environment.
 #' See examples for offline use. All layers use the Lambert azimuthal equal-area projection
-#'  (EPSG:6932; CRS:+proj=laea +lat_0=-90 +lon_0=0 +x_0=0 +y_0=0 +datum=WGS84 +units=m +no_defs)
+#'  (\code{\link{CCAMLRp}})
 #'
 #' @seealso 
 #' \code{\link{load_ASDs}}, \code{\link{load_SSRUs}}, \code{\link{load_RBs}},
@@ -201,12 +206,13 @@ load_SSMUs=function(){
 #' 
 #' #When online:
 #' MAs=load_MAs()
-#' plot(MAs)
+#' plot(st_geometry(MAs))
 #' 
 #' #If going offline in the future: load and save as RData when online,
-#' # then reload RData when offline:
+#' #then reload RData when offline:
 #' MAs=load_MAs()
 #' EEZs=load_EEZs()
+#' #N.B.: replace tempdir() with folder location of your choice
 #' save(list=c('MAs','EEZs'), file = file.path(tempdir(), "CCAMLRLayers.RData"))
 #' rm(MAs,EEZs)
 #' load(file.path(tempdir(), "CCAMLRLayers.RData"))
@@ -216,16 +222,16 @@ load_SSMUs=function(){
 load_MAs=function(){
   #NB: use http not https
   ccamlrgisurl="http://gis.ccamlr.org/geoserver/gis/ows?service=WFS&version=1.0.0&request=GetFeature&typeName=gis:omas_6932&outputFormat=json"
-  CCAMLR_data=suppressWarnings(readOGR(dsn=ccamlrgisurl,layer="OGRGeoJSON",verbose = FALSE))
-  CCAMLR_data=spTransform(CCAMLR_data,CRS("+init=epsg:6932"))
+  CCAMLR_data = st_read(ccamlrgisurl,quiet = TRUE)
+  CCAMLR_data = st_transform(CCAMLR_data,6932)
   return(CCAMLR_data)
 }
 
 #' Load CCAMLR Marine Protected Areas
 #'
-#' Download the up-to-date spatial layer from the \href{http://gis.ccamlr.org/}{online CCAMLRGIS} and load it to your environment.
+#' Download the up-to-date spatial layer from the online CCAMLRGIS (\url{http://gis.ccamlr.org/}) and load it to your environment.
 #' See examples for offline use. All layers use the Lambert azimuthal equal-area projection
-#'  (EPSG:6932; CRS:+proj=laea +lat_0=-90 +lon_0=0 +x_0=0 +y_0=0 +datum=WGS84 +units=m +no_defs)
+#'  (\code{\link{CCAMLRp}})
 #'
 #' @seealso 
 #' \code{\link{load_ASDs}}, \code{\link{load_SSRUs}}, \code{\link{load_RBs}},
@@ -238,12 +244,13 @@ load_MAs=function(){
 #' 
 #' #When online:
 #' MPAs=load_MPAs()
-#' plot(MPAs)
+#' plot(st_geometry(MPAs))
 #' 
 #' #If going offline in the future: load and save as RData when online,
-#' # then reload RData when offline:
+#' #then reload RData when offline:
 #' MPAs=load_MPAs()
 #' EEZs=load_EEZs()
+#' #N.B.: replace tempdir() with folder location of your choice
 #' save(list=c('MPAs','EEZs'), file = file.path(tempdir(), "CCAMLRLayers.RData"))
 #' rm(MPAs,EEZs)
 #' load(file.path(tempdir(), "CCAMLRLayers.RData"))
@@ -254,16 +261,16 @@ load_MAs=function(){
 load_MPAs=function(){
   #NB: use http not https
   ccamlrgisurl="http://gis.ccamlr.org/geoserver/gis/ows?service=WFS&version=1.0.0&request=GetFeature&typeName=gis:mpas_6932&outputFormat=json"
-  CCAMLR_data=suppressWarnings(readOGR(dsn=ccamlrgisurl,layer="OGRGeoJSON",verbose = FALSE))
-  CCAMLR_data=spTransform(CCAMLR_data,CRS("+init=epsg:6932"))
+  CCAMLR_data = st_read(ccamlrgisurl,quiet = TRUE)
+  CCAMLR_data = st_transform(CCAMLR_data,6932)
   return(CCAMLR_data)
 }
 
 #' Load Exclusive Economic Zones
 #' 
-#' Download the up-to-date spatial layer from the \href{http://gis.ccamlr.org/}{online CCAMLRGIS} and load it to your environment.
+#' Download the up-to-date spatial layer from the online CCAMLRGIS (\url{http://gis.ccamlr.org/}) and load it to your environment.
 #' See examples for offline use. All layers use the Lambert azimuthal equal-area projection
-#'  (EPSG:6932; CRS:+proj=laea +lat_0=-90 +lon_0=0 +x_0=0 +y_0=0 +datum=WGS84 +units=m +no_defs)
+#'  (\code{\link{CCAMLRp}})
 #'
 #' @seealso 
 #' \code{\link{load_ASDs}}, \code{\link{load_SSRUs}}, \code{\link{load_RBs}},
@@ -276,12 +283,13 @@ load_MPAs=function(){
 #' 
 #' #When online:
 #' EEZs=load_EEZs()
-#' plot(EEZs)
+#' plot(st_geometry(EEZs))
 #' 
 #' #If going offline in the future: load and save as RData when online,
-#' # then reload RData when offline:
+#' #then reload RData when offline:
 #' MPAs=load_MPAs()
 #' EEZs=load_EEZs()
+#' #N.B.: replace tempdir() with folder location of your choice
 #' save(list=c('MPAs','EEZs'), file = file.path(tempdir(), "CCAMLRLayers.RData"))
 #' rm(MPAs,EEZs)
 #' load(file.path(tempdir(), "CCAMLRLayers.RData"))
@@ -292,14 +300,14 @@ load_MPAs=function(){
 load_EEZs=function(){
   #NB: use http not https
   ccamlrgisurl="http://gis.ccamlr.org/geoserver/gis/ows?service=WFS&version=1.0.0&request=GetFeature&typeName=gis:eez_6932&outputFormat=json"
-  CCAMLR_data=suppressWarnings(readOGR(dsn=ccamlrgisurl,layer="OGRGeoJSON",verbose = FALSE))
-  CCAMLR_data=spTransform(CCAMLR_data,CRS("+init=epsg:6932"))
+  CCAMLR_data = st_read(ccamlrgisurl,quiet = TRUE)
+  CCAMLR_data = st_transform(CCAMLR_data,6932)
   return(CCAMLR_data)
 }
 
 #' Load Bathymetry data
 #' 
-#' Download the up-to-date projected GEBCO data from the \href{http://gis.ccamlr.org/}{online CCAMLRGIS} and load it to your environment.
+#' Download the up-to-date projected GEBCO data from the online CCAMLRGIS (\url{http://gis.ccamlr.org/}) and load it to your environment.
 #' This functions can be used in two steps, to first download the data and then use it. If you keep the downloaded data, you can then
 #' re-use it in all your scripts.
 #' 
@@ -310,14 +318,14 @@ load_EEZs=function(){
 #' 
 #' To re-use the downloaded data, you must provide the full path to that file, for example:
 #' 
-#' "C:/Desktop/GEBCO2020_5000.tif".
+#' \code{LocalFile="C:/Desktop/GEBCO2021_5000.tif"}.
 #' 
 #' This data was reprojected from the original GEBCO Grid after cropping at 40 degrees South. Projection was made using the Lambert
-#' azimuthal equal-area projection (EPSG:6932; CRS:+proj=laea +lat_0=-90 +lon_0=0 +x_0=0 +y_0=0 +datum=WGS84 +units=m +no_defs),
-#' and the data was aggregated at a several resolutions.
+#' azimuthal equal-area projection (\code{\link{CCAMLRp}}),
+#' and the data was aggregated at several resolutions.
 #' 
 #' @param LocalFile To download the data, set to \code{FALSE}. To re-use a downloaded file, set to the full path of the file 
-#' (e.g., "C:/Desktop/GEBCO2020_5000.tif").
+#' (e.g., \code{LocalFile="C:/Desktop/GEBCO2021_5000.tif"}).
 #' @param Res Desired resolution in meters. May only be one of: 500, 1000, 2500 or 5000.
 #' @return Bathymetry raster.
 #' 
@@ -325,12 +333,9 @@ load_EEZs=function(){
 #' \code{\link{add_col}}, \code{\link{add_Cscale}}, \code{\link{Depth_cols}}, \code{\link{Depth_cuts}},
 #' \code{\link{Depth_cols2}}, \code{\link{Depth_cuts2}}, \code{\link{get_depths}},
 #' \code{\link{create_Stations}},
-#' \code{\link{SmallBathy}}, \code{\link{load_SSRUs}}, \code{\link{load_RBs}},
-#' \code{\link{load_ASDs}}, \code{\link{load_SSRUs}}, \code{\link{load_RBs}},
-#' \code{\link{load_SSMUs}}, \code{\link{load_MAs}}, \code{\link{load_Coastline}},
-#' \code{\link{load_MPAs}}, \code{\link{load_EEZs}}.
+#' \code{\link{SmallBathy}}.
 #' 
-#' @references GEBCO Compilation Group (2020) GEBCO 2020 Grid (doi:10.5285/a29c5465-b138-234d-e053-6c86abc040b9) 
+#' @references GEBCO Compilation Group (2021) GEBCO 2021 Grid (doi:10.5285/c6612cbe-50b3-0cff-e053-6c86abc09f8f) 
 #' 
 #' @export
 #' @examples  
@@ -340,11 +345,11 @@ load_EEZs=function(){
 #' 
 #' ##Download the data. It will go in the folder given by getwd():
 #' #Bathy=load_Bathy(LocalFile = FALSE,Res=5000)
-#' #plot(Bathy, breaks=Depth_cuts,col=Depth_cols,axes=FALSE,box=FALSE,legend=F)
+#' #plot(Bathy, breaks=Depth_cuts,col=Depth_cols,axes=FALSE)
 #' 
-#' ##Re-use the downloaded data (provided it's here: "C:/Desktop/GEBCO2020_5000.tif"):
-#' #Bathy=load_Bathy(LocalFile = "C:/Desktop/GEBCO2020_5000.tif")
-#' #plot(Bathy, breaks=Depth_cuts,col=Depth_cols,axes=FALSE,box=FALSE,legend=F)
+#' ##Re-use the downloaded data (provided it's here: "C:/Desktop/GEBCO2021_5000.tif"):
+#' #Bathy=load_Bathy(LocalFile = "C:/Desktop/GEBCO2021_5000.tif")
+#' #plot(Bathy, breaks=Depth_cuts,col=Depth_cols,axes=FALSE)
 #' 
 #' }
 #' 
@@ -352,13 +357,13 @@ load_EEZs=function(){
 load_Bathy=function(LocalFile,Res=5000){
   if(LocalFile==FALSE){
     if(Res%in%c(500,1000,2500,5000)==FALSE){stop("'Res' should be one of: 500, 1000, 2500 or 5000")}
-    Fname=paste0("GEBCO2020_",Res,".tif")
+    Fname=paste0("GEBCO2021_",Res,".tif")
     url=paste0("https://gis.ccamlr.org/geoserver/www/",Fname)
     download.file(url, destfile=paste0(getwd(),"/",Fname),mode="wb")
-    Bathy=raster::raster(paste0(getwd(),"/",Fname))
+    Bathy=terra::rast(paste0(getwd(),"/",Fname))
   }else{
     if(file.exists(LocalFile)==FALSE){stop("File not found. Either the file is missing or 'LocalFile' is not properly set.")}
-    Bathy=raster::raster(LocalFile)
+    Bathy=terra::rast(LocalFile)
   }
   return(Bathy)
-}
\ No newline at end of file
+}
